@@ -45,11 +45,6 @@ long dym_dynamical_matrices_with_dd_openmp_over_qpoints(
     const double *q_direction, const double nac_factor,
     const double (*dd_q0)[2], const double (*G_list)[3],
     const long num_G_points, const double lambda, const long use_Wang_NAC);
-long dym_get_dynamical_matrices_openmp_over_qpoints(
-    double (*dynamical_matrices)[2], const long num_patom, const long num_satom,
-    const double *fc, const double (*qpoints)[3], const long n_qpoints,
-    const double (*svecs)[3], const long (*multi)[2], const double *mass,
-    const long *s2p_map, const long *p2s_map, const double (*charge_sum)[3][3]);
 long dym_get_dynamical_matrix_at_q(double (*dynamical_matrix)[2],
                                    const long num_patom, const long num_satom,
                                    const double *fc, const double q[3],
