@@ -646,6 +646,13 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
         default=None,
         help="Output projected thermal properties",
     )
+    parser.add_argument(
+        "--pypolymlp",
+        dest="use_pypolymlp",
+        action="store_true",
+        default=None,
+        help="Use pypolymlp for generating force constants",
+    )
     parser.add_argument(
         "--qpoints",
         nargs="+",
@@ -755,6 +762,13 @@ def get_parser(fc_symmetry=False, is_nac=False, load_phonopy_yaml=False):
     parser.add_argument(
         "--sigma", dest="sigma", default=None, help="Smearing width for DOS"
     )
+    parser.add_argument(
+        "--symfc",
+        dest="use_symfc",
+        action="store_true",
+        default=None,
+        help="Use symfc for generating force constants",
+    )
     parser.add_argument(
         "--symmetry",
         dest="is_check_symmetry",
