@@ -53,6 +53,7 @@ def Atoms(*args, **kwargs):
         "phonopy.atoms.Atoms is deprecated. Please use "
         "PhonopyAtoms instead of Atoms.",
         DeprecationWarning,
+        stacklevel=2,
     )
     return PhonopyAtoms(*args, **kwargs)
 
@@ -108,12 +109,14 @@ class PhonopyAtoms:
                 "PhonopyAtoms.__init__ parameter of magmoms is deprecated. "
                 "Use magnetic_moments instead.",
                 DeprecationWarning,
+                stacklevel=2,
             )
         if pbc is not None:
             warnings.warn(
                 "PhonopyAtoms.__init__ parameter of pbc is deprecated. "
                 "It is considered always True.",
                 DeprecationWarning,
+                stacklevel=2,
             )
         if atoms:
             self._set_parameters(
@@ -192,6 +195,7 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.set_cell() is deprecated. Use cell attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.cell = cell
 
@@ -200,13 +204,16 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.get_cell() is deprecated. Use cell attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.cell
 
     @property
     def positions(self):
         """Setter and getter of positions in Cartesian coordinates."""
-        return np.dot(self._scaled_positions, self._cell)
+        return np.array(
+            np.dot(self._scaled_positions, self._cell), dtype="double", order="C"
+        )
 
     @positions.setter
     def positions(self, positions):
@@ -219,6 +226,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.get_positions() is deprecated. "
             "Use positions attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.positions
 
@@ -228,6 +236,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.set_positions() is deprecated. "
             "Use positions attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.positions = positions
 
@@ -247,6 +256,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.get_scaled_positions() is deprecated. "
             "Use scaled_positions attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.scaled_positions
 
@@ -256,6 +266,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.set_scaled_positions() is deprecated. "
             "Use scaled_positions attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.scaled_positions = scaled_positions
 
@@ -277,6 +288,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.get_chemical_symbols() is deprecated. "
             "Use symbols attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.symbols
 
@@ -286,6 +298,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.set_chemical_symbols() is deprecated. "
             "Use symbols attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.symbols = symbols
 
@@ -307,6 +320,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.get_atomic_numbers() is deprecated. "
             "Use numbers attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.numbers
 
@@ -316,6 +330,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.set_atomic_numbers() is deprecated. "
             "Use numbers attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.numbers = numbers
 
@@ -337,6 +352,7 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.get_masses() is deprecated. Use masses attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.masses
 
@@ -345,6 +361,7 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.set_masses() is deprecated. Use masses attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.masses = masses
 
@@ -376,6 +393,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.get_magnetic_moments() is deprecated. "
             "Use magnetic_moments attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.magnetic_moments
 
@@ -385,6 +403,7 @@ class PhonopyAtoms:
             "PhonopyAtoms.set_magnetic_moments() is deprecated. "
             "Use magnetic_moments attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         self.magnetic_moments = magmoms
 
@@ -398,6 +417,7 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.get_volume() is deprecated. " "Use volume attribute instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.volume
 
@@ -535,6 +555,7 @@ class PhonopyAtoms:
         warnings.warn(
             "PhonopyAtoms.to_tuple() is deprecated. Use totuple() instead.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.totuple()
 
