@@ -124,6 +124,7 @@ class Supercell(PhonopyAtoms):
             "Supercell.get_supercell_matrix() is deprecated."
             "Use Supercell.supercell_matrix attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.supercell_matrix
 
@@ -148,6 +149,7 @@ class Supercell(PhonopyAtoms):
             "Supercell.get_supercell_to_unitcell_map() is deprecated."
             "Use Supercell.s2u_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.s2u_map
 
@@ -172,6 +174,7 @@ class Supercell(PhonopyAtoms):
             "Supercell.get_unitcell_to_supercell_map() is deprecated."
             "Use Supercell.u2s_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.u2s_map
 
@@ -194,6 +197,7 @@ class Supercell(PhonopyAtoms):
             "Supercell.get_unitcell_to_unitcell_map() is deprecated."
             "Use Supercell.u2s_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.u2u_map
 
@@ -409,6 +413,7 @@ class Primitive(PhonopyAtoms):
             "Primitive.get_primitive_matrix() is deprecated."
             "Use Primitive.primitive_matrix attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.primitive_matrix
 
@@ -432,6 +437,7 @@ class Primitive(PhonopyAtoms):
             "Primitive.get_primitive_to_supercell_map() is deprecated."
             "Use Primitive.p2s_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.p2s_map
 
@@ -455,6 +461,7 @@ class Primitive(PhonopyAtoms):
             "Primitive.get_supercell_to_primitive_map() is deprecated."
             "Use Primitive.s2p_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.s2p_map
 
@@ -478,6 +485,7 @@ class Primitive(PhonopyAtoms):
             "Primitive.get_primitive_to_primitive_map() is deprecated."
             "Use Primitive.p2p_map attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.p2p_map
 
@@ -535,6 +543,7 @@ class Primitive(PhonopyAtoms):
             "Primitive.get_atomic_permutations() is deprecated."
             "Use Primitive.atomic_permutations attribute.",
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.atomic_permutations
 
@@ -1054,7 +1063,7 @@ def get_reduced_bases(lattice, method="niggli", tolerance=1e-5):
         Tolerance to find shortest basis vecotrs
 
     Returns
-    --------
+    -------
     Reduced basis as row vectors, [a_red, b_red, c_red]^T
         dtype='double'
         shape=(3, 3)
@@ -1392,7 +1401,10 @@ def compute_all_sg_permutations(
 
 
 def compute_permutation_for_rotation(
-    positions_a, positions_b, lattice, symprec  # scaled positions  # column vectors
+    positions_a: np.ndarray,
+    positions_b: np.ndarray,
+    lattice: np.ndarray,
+    symprec: float,
 ):
     """Get the overall permutation such that.
 
@@ -1459,7 +1471,10 @@ def compute_permutation_for_rotation(
 
 
 def _compute_permutation_c(
-    positions_a, positions_b, lattice, symprec  # scaled positions  # column vectors
+    positions_a,
+    positions_b,
+    lattice,
+    symprec,  # scaled positions  # column vectors
 ):
     """Return mapping defined by positions_a[perm[i]] == positions_b[i].
 
@@ -1499,7 +1514,7 @@ def _compute_permutation_c(
                 "It is recommended to symmetrize crystal structure well "
                 "and then re-start phonon calculation from scratch."
             )
-            warnings.warn(msg)
+            warnings.warn(msg, stacklevel=2)
 
         if not is_found:
             permutation_error()
