@@ -38,14 +38,6 @@ import warnings
 
 import numpy as np
 
-try:
-    import phonopy._phonopy as phonoc
-except ImportError:
-    import sys
-
-    print("Phonopy C-extension has to be built properly.")
-    sys.exit(1)
-
 
 def get_tetrahedra_relative_grid_address(microzone_lattice, lang="C"):
     """Return relative (differences of) grid addresses from the central.
@@ -57,6 +49,14 @@ def get_tetrahedra_relative_grid_address(microzone_lattice, lang="C"):
         microzone_lattice = np.linalg.inv(cell.get_cell()) / mesh
 
     """
+    try:
+        import phonopy._phonopy as phonoc
+    except ImportError:
+        import sys
+
+        print("Phonopy C-extension has to be built properly.")
+        sys.exit(1)
+
     relative_grid_address = np.zeros((24, 4, 3), dtype="int_", order="C")
     if lang == "C":
         phonoc.tetrahedra_relative_grid_address(
@@ -76,6 +76,14 @@ def get_all_tetrahedra_relative_grid_address(lang="C"):
     This exists only for the test.
 
     """
+    try:
+        import phonopy._phonopy as phonoc
+    except ImportError:
+        import sys
+
+        print("Phonopy C-extension has to be built properly.")
+        sys.exit(1)
+
     relative_grid_address = np.zeros((4, 24, 4, 3), dtype="int_", order="C")
     if lang == "C":
         phonoc.all_tetrahedra_relative_grid_address(relative_grid_address)
@@ -103,6 +111,14 @@ def get_tetrahedra_integration_weight(omegas, tetrahedra_omegas, function="I"):
         'J' is for intetration and 'I' is for its derivative.
 
     """
+    try:
+        import phonopy._phonopy as phonoc
+    except ImportError:
+        import sys
+
+        print("Phonopy C-extension has to be built properly.")
+        sys.exit(1)
+
     if isinstance(omegas, float):
         return phonoc.tetrahedra_integration_weight(
             omegas, np.array(tetrahedra_omegas, dtype="double", order="C"), function
@@ -186,6 +202,7 @@ class TetrahedronMethod:
                 "Use TetrahedronMethod.tetrahedra attribute instead."
             ),
             DeprecationWarning,
+            stacklevel=2,
         )
         return self.tetrahedra
 
@@ -308,7 +325,7 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._J_13()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 2:
             if ci == 0:
                 return self._J_20()
@@ -319,7 +336,7 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._J_23()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 3:
             if ci == 0:
                 return self._J_30()
@@ -330,11 +347,11 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._J_33()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 4:
             return self._J_4()
         else:
-            assert False
+            raise RuntimeError("Unexpected condition encountered.")
 
     def _I(self, i, ci):
         if i == 0:
@@ -349,7 +366,7 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._I_13()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 2:
             if ci == 0:
                 return self._I_20()
@@ -360,7 +377,7 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._I_23()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 3:
             if ci == 0:
                 return self._I_30()
@@ -371,11 +388,11 @@ class TetrahedronMethod:
             elif ci == 3:
                 return self._I_33()
             else:
-                assert False
+                raise RuntimeError("Unexpected condition encountered.")
         elif i == 4:
             return self._I_4()
         else:
-            assert False
+            raise RuntimeError("Unexpected condition encountered.")
 
     def _n(self, i):
         if i == 0:
@@ -389,7 +406,7 @@ class TetrahedronMethod:
         elif i == 4:
             return self._n_4()
         else:
-            assert False
+            raise RuntimeError("Unexpected condition encountered.")
 
     def _g(self, i):
         if i == 0:
@@ -403,7 +420,7 @@ class TetrahedronMethod:
         elif i == 4:
             return self._g_4()
         else:
-            assert False
+            raise RuntimeError("Unexpected condition encountered.")
 
     def _n_0(self):
         """n0.
@@ -710,7 +727,7 @@ def _create_tetrahedra(shortest_main_diagonal):
         pairs = ((0, 1), (0, 2), (1, 5), (2, 6), (5, 7), (6, 7))
         six_tetras = np.sort([[3, 4] + list(x) for x in pairs])
     else:
-        assert False
+        RuntimeError("Unexpected condition encountered.")
 
     return six_tetras
 
